==> pythonmagick_0.8.orig.tar.gz: PythonMagick-0.8/pythonmagick_src/_main.cpp <==
// Include =====================================================================
#include <boost/python/module.hpp>

// Exports =====================================================================
void Export_pyste_src_VPath();
void Export_pyste_src_TypeMetric();
void Export_pyste_src_Pixels();
void Export_pyste_src_PathSmoothQuadraticCurvetoRel();
void Export_pyste_src_PathSmoothQuadraticCurvetoAbs();
void Export_pyste_src_PathSmoothCurvetoRel();
void Export_pyste_src_PathSmoothCurvetoAbs();
void Export_pyste_src_PathQuadraticCurvetoRel();
void Export_pyste_src_PathQuadraticCurvetoArgs();
void Export_pyste_src_PathQuadraticCurvetoAbs();
void Export_pyste_src_PathMovetoRel();
void Export_pyste_src_PathMovetoAbs();
void Export_pyste_src_PathLinetoVerticalRel();
void Export_pyste_src_PathLinetoVerticalAbs();
void Export_pyste_src_PathLinetoRel();
void Export_pyste_src_PathLinetoHorizontalRel();
void Export_pyste_src_PathLinetoHorizontalAbs();
void Export_pyste_src_PathLinetoAbs();
void Export_pyste_src_PathCurvetoRel();
void Export_pyste_src_PathCurvetoArgs();
void Export_pyste_src_PathCurvetoAbs();
void Export_pyste_src_PathClosePath();
void Export_pyste_src_PathArcRel();
void Export_pyste_src_PathArcArgs();
void Export_pyste_src_PathArcAbs();
void Export_pyste_src_Image();
void Export_pyste_src_Geometry();
void Export_pyste_src_Exception();
void Export_pyste_src_DrawableViewbox();
void Export_pyste_src_DrawableTranslation();
void Export_pyste_src_DrawableTextUnderColor();
void Export_pyste_src_DrawableTextDecoration();
void Export_pyste_src_DrawableTextAntialias();
void Export_pyste_src_DrawableText();
void Export_pyste_src_DrawableStrokeWidth();
void Export_pyste_src_DrawableStrokeOpacity();
void Export_pyste_src_DrawableStrokeLineJoin();
void Export_pyste_src_DrawableStrokeLineCap();
void Export_pyste_src_DrawableStrokeColor();
void Export_pyste_src_DrawableStrokeAntialias();
void Export_pyste_src_DrawableSkewY();
void Export_pyste_src_DrawableSkewX();
void Export_pyste_src_DrawableScaling();
void Export_pyste_src_DrawableRoundRectangle();
void Export_pyste_src_DrawableRotation();
void Export_pyste_src_DrawableRectangle();
void Export_pyste_src_DrawablePushPattern();
void Export_pyste_src_DrawablePushGraphicContext();
void Export_pyste_src_DrawablePushClipPath();
void Export_pyste_src_DrawablePopPattern();
void Export_pyste_src_DrawablePopGraphicContext();
void Export_pyste_src_DrawablePopClipPath();
void Export_pyste_src_DrawablePolyline();
void Export_pyste_src_DrawablePolygon();
void Export_pyste_src_DrawablePointSize();
void Export_pyste_src_DrawablePoint();
void Export_pyste_src_DrawablePath();
void Export_pyste_src_DrawableMiterLimit();
void Export_pyste_src_DrawableMatte();
void Export_pyste_src_DrawableLine();
void Export_pyste_src_DrawableGravity();
void Export_pyste_src_DrawableFont();
void Export_pyste_src_DrawableFillRule();
void Export_pyste_src_DrawableFillOpacity();
void Export_pyste_src_DrawableFillColor();
void Export_pyste_src_DrawableEllipse();
void Export_pyste_src_DrawableDashOffset();
void Export_pyste_src_DrawableDashArray();
void Export_pyste_src_DrawableCompositeImage();
void Export_pyste_src_DrawableColor();
void Export_pyste_src_DrawableClipPath();
void Export_pyste_src_DrawableCircle();
void Export_pyste_src_DrawableBezier();
void Export_pyste_src_DrawableArc();
void Export_pyste_src_DrawableAffine();
void Export_pyste_src_Drawable();
void Export_pyste_src_Coordinate();
void Export_pyste_src_Color();
void Export_pyste_src_Blob();

// Module ======================================================================
BOOST_PYTHON_MODULE(_PythonMagick)
{
    Export_pyste_src_VPath();
    Export_pyste_src_TypeMetric();
    Export_pyste_src_Pixels();
    Export_pyste_src_PathSmoothQuadraticCurvetoRel();
    Export_pyste_src_PathSmoothQuadraticCurvetoAbs();
    Export_pyste_src_PathSmoothCurvetoRel();
    Export_pyste_src_PathSmoothCurvetoAbs();
    Export_pyste_src_PathQuadraticCurvetoRel();
    Export_pyste_src_PathQuadraticCurvetoArgs();
    Export_pyste_src_PathQuadraticCurvetoAbs();
    Export_pyste_src_PathMovetoRel();
    Export_pyste_src_PathMovetoAbs();
    Export_pyste_src_PathLinetoVerticalRel();
    Export_pyste_src_PathLinetoVerticalAbs();
    Export_pyste_src_PathLinetoRel();
    Export_pyste_src_PathLinetoHorizontalRel();
    Export_pyste_src_PathLinetoHorizontalAbs();
    Export_pyste_src_PathLinetoAbs();
    Export_pyste_src_PathCurvetoRel();
    Export_pyste_src_PathCurvetoArgs();
    Export_pyste_src_PathCurvetoAbs();
    Export_pyste_src_PathClosePath();
    Export_pyste_src_PathArcRel();
    Export_pyste_src_PathArcArgs();
    Export_pyste_src_PathArcAbs();
    Export_pyste_src_Image();
    Export_pyste_src_Geometry();
    Export_pyste_src_Exception();
    Export_pyste_src_DrawableViewbox();
    Export_pyste_src_DrawableTranslation();
    Export_pyste_src_DrawableTextUnderColor();
    Export_pyste_src_DrawableTextDecoration();
    Export_pyste_src_DrawableTextAntialias();
    Export_pyste_src_DrawableText();
    Export_pyste_src_DrawableStrokeWidth();
    Export_pyste_src_DrawableStrokeOpacity();
    Export_pyste_src_DrawableStrokeLineJoin();
    Export_pyste_src_DrawableStrokeLineCap();
    Export_pyste_src_DrawableStrokeColor();
    Export_pyste_src_DrawableStrokeAntialias();
    Export_pyste_src_DrawableSkewY();
    Export_pyste_src_DrawableSkewX();
    Export_pyste_src_DrawableScaling();
    Export_pyste_src_DrawableRoundRectangle();
    Export_pyste_src_DrawableRotation();
    Export_pyste_src_DrawableRectangle();
    Export_pyste_src_DrawablePushPattern();
    Export_pyste_src_DrawablePushGraphicContext();
    Export_pyste_src_DrawablePushClipPath();
    Export_pyste_src_DrawablePopPattern();
    Export_pyste_src_DrawablePopGraphicContext();
    Export_pyste_src_DrawablePopClipPath();
    Export_pyste_src_DrawablePolyline();
    Export_pyste_src_DrawablePolygon();
    Export_pyste_src_DrawablePointSize();
    Export_pyste_src_DrawablePoint();
    Export_pyste_src_DrawablePath();
    Export_pyste_src_DrawableMiterLimit();
    Export_pyste_src_DrawableMatte();
    Export_pyste_src_DrawableLine();
    Export_pyste_src_DrawableGravity();
    Export_pyste_src_DrawableFont();
    Export_pyste_src_DrawableFillRule();
    Export_pyste_src_DrawableFillOpacity();
    Export_pyste_src_DrawableFillColor();
    Export_pyste_src_DrawableEllipse();
    Export_pyste_src_DrawableDashOffset();
    Export_pyste_src_DrawableDashArray();
    Export_pyste_src_DrawableCompositeImage();
    Export_pyste_src_DrawableColor();
    Export_pyste_src_DrawableClipPath();
    Export_pyste_src_DrawableCircle();
    Export_pyste_src_DrawableBezier();
    Export_pyste_src_DrawableArc();
    Export_pyste_src_DrawableAffine();
    Export_pyste_src_Drawable();
    Export_pyste_src_Coordinate();
    Export_pyste_src_Color();
    Export_pyste_src_Blob();
}

==> pythonmagick_0.9.11.orig.tar.gz: PythonMagick-0.9.11/pythonmagick_src/_main.cpp <==
// Include =====================================================================
#include <boost/python/module.hpp>

// Exports =====================================================================
void Export_pyste_src_VPath();
void Export_pyste_src_TypeMetric();
void Export_pyste_src_Pixels();
void Export_pyste_src_PathSmoothQuadraticCurvetoRel();
void Export_pyste_src_PathSmoothQuadraticCurvetoAbs();
void Export_pyste_src_PathSmoothCurvetoRel();
void Export_pyste_src_PathSmoothCurvetoAbs();
void Export_pyste_src_PathQuadraticCurvetoRel();
void Export_pyste_src_PathQuadraticCurvetoArgs();
void Export_pyste_src_PathQuadraticCurvetoAbs();
void Export_pyste_src_PathMovetoRel();
void Export_pyste_src_PathMovetoAbs();
void Export_pyste_src_PathLinetoVerticalRel();
void Export_pyste_src_PathLinetoVerticalAbs();
void Export_pyste_src_PathLinetoRel();
void Export_pyste_src_PathLinetoHorizontalRel();
void Export_pyste_src_PathLinetoHorizontalAbs();
void Export_pyste_src_PathLinetoAbs();
void Export_pyste_src_PathCurvetoRel();
void Export_pyste_src_PathCurvetoArgs();
void Export_pyste_src_PathCurvetoAbs();
void Export_pyste_src_PathClosePath();
void Export_pyste_src_PathArcRel();
void Export_pyste_src_PathArcArgs();
void Export_pyste_src_PathArcAbs();
void Export_pyste_src_Image();
void Export_pyste_src_GravityType();
void Export_pyste_src_Geometry();
void Export_pyste_src_FilterTypes();
void Export_pyste_src_Exception();
void Export_pyste_src_DrawableViewbox();
void Export_pyste_src_DrawableTranslation();
void Export_pyste_src_DrawableTextUnderColor();
void Export_pyste_src_DrawableTextDecoration();
void Export_pyste_src_DrawableTextAntialias();
void Export_pyste_src_DrawableText();
void Export_pyste_src_DrawableStrokeWidth();
void Export_pyste_src_DrawableStrokeOpacity();
void Export_pyste_src_DrawableStrokeLineJoin();
void Export_pyste_src_DrawableStrokeLineCap();
void Export_pyste_src_DrawableStrokeColor();
void Export_pyste_src_DrawableStrokeAntialias();
void Export_pyste_src_DrawableSkewY();
void Export_pyste_src_DrawableSkewX();
void Export_pyste_src_DrawableScaling();
void Export_pyste_src_DrawableRoundRectangle();
void Export_pyste_src_DrawableRotation();
void Export_pyste_src_DrawableRectangle();
void Export_pyste_src_DrawablePushPattern();
void Export_pyste_src_DrawablePushGraphicContext();
void Export_pyste_src_DrawablePushClipPath();
void Export_pyste_src_DrawablePopPattern();
void Export_pyste_src_DrawablePopGraphicContext();
void Export_pyste_src_DrawablePopClipPath();
void Export_pyste_src_DrawablePolyline();
void Export_pyste_src_DrawablePolygon();
void Export_pyste_src_DrawablePointSize();
void Export_pyste_src_DrawablePoint();
void Export_pyste_src_DrawablePath();
void Export_pyste_src_DrawableMiterLimit();
void Export_pyste_src_DrawableMatte();
void Export_pyste_src_DrawableLine();
void Export_pyste_src_DrawableGravity();
void Export_pyste_src_DrawableFont();
void Export_pyste_src_DrawableFillRule();
void Export_pyste_src_DrawableFillOpacity();
void Export_pyste_src_DrawableFillColor();
void Export_pyste_src_DrawableEllipse();
void Export_pyste_src_DrawableDashOffset();
void Export_pyste_src_DrawableDashArray();
void Export_pyste_src_DrawableCompositeImage();
void Export_pyste_src_DrawableColor();
void Export_pyste_src_DrawableClipPath();
void Export_pyste_src_DrawableCircle();
void Export_pyste_src_DrawableBezier();
void Export_pyste_src_DrawableArc();
void Export_pyste_src_DrawableAffine();
void Export_pyste_src_Drawable();
void Export_pyste_src_DecorationType();
void Export_pyste_src_Coordinate();
void Export_pyste_src_CompressionType();
void Export_pyste_src_CompositeOperator();
void Export_pyste_src_Color();
void Export_pyste_src_Blob();
void Export_pyste_src_ColorspaceType();

// Module ======================================================================
BOOST_PYTHON_MODULE(_PythonMagick)
{
    Export_pyste_src_VPath();
    Export_pyste_src_TypeMetric();
    Export_pyste_src_Pixels();
    Export_pyste_src_PathSmoothQuadraticCurvetoRel();
    Export_pyste_src_PathSmoothQuadraticCurvetoAbs();
    Export_pyste_src_PathSmoothCurvetoRel();
    Export_pyste_src_PathSmoothCurvetoAbs();
    Export_pyste_src_PathQuadraticCurvetoRel();
    Export_pyste_src_PathQuadraticCurvetoArgs();
    Export_pyste_src_PathQuadraticCurvetoAbs();
    Export_pyste_src_PathMovetoRel();
    Export_pyste_src_PathMovetoAbs();
    Export_pyste_src_PathLinetoVerticalRel();
    Export_pyste_src_PathLinetoVerticalAbs();
    Export_pyste_src_PathLinetoRel();
    Export_pyste_src_PathLinetoHorizontalRel();
    Export_pyste_src_PathLinetoHorizontalAbs();
    Export_pyste_src_PathLinetoAbs();
    Export_pyste_src_PathCurvetoRel();
    Export_pyste_src_PathCurvetoArgs();
    Export_pyste_src_PathCurvetoAbs();
    Export_pyste_src_PathClosePath();
    Export_pyste_src_PathArcRel();
    Export_pyste_src_PathArcArgs();
    Export_pyste_src_PathArcAbs();
    Export_pyste_src_Image();
    Export_pyste_src_GravityType();
    Export_pyste_src_Geometry();
    Export_pyste_src_FilterTypes();
    Export_pyste_src_Exception();
    Export_pyste_src_DrawableViewbox();
    Export_pyste_src_DrawableTranslation();
    Export_pyste_src_DrawableTextUnderColor();
    Export_pyste_src_DrawableTextDecoration();
    Export_pyste_src_DrawableTextAntialias();
    Export_pyste_src_DrawableText();
    Export_pyste_src_DrawableStrokeWidth();
    Export_pyste_src_DrawableStrokeOpacity();
    Export_pyste_src_DrawableStrokeLineJoin();
    Export_pyste_src_DrawableStrokeLineCap();
    Export_pyste_src_DrawableStrokeColor();
    Export_pyste_src_DrawableStrokeAntialias();
    Export_pyste_src_DrawableSkewY();
    Export_pyste_src_DrawableSkewX();
    Export_pyste_src_DrawableScaling();
    Export_pyste_src_DrawableRoundRectangle();
    Export_pyste_src_DrawableRotation();
    Export_pyste_src_DrawableRectangle();
    Export_pyste_src_DrawablePushPattern();
    Export_pyste_src_DrawablePushGraphicContext();
    Export_pyste_src_DrawablePushClipPath();
    Export_pyste_src_DrawablePopPattern();
    Export_pyste_src_DrawablePopGraphicContext();
    Export_pyste_src_DrawablePopClipPath();
    Export_pyste_src_DrawablePolyline();
    Export_pyste_src_DrawablePolygon();
    Export_pyste_src_DrawablePointSize();
    Export_pyste_src_DrawablePoint();
    Export_pyste_src_DrawablePath();
    Export_pyste_src_DrawableMiterLimit();
    Export_pyste_src_DrawableMatte();
    Export_pyste_src_DrawableLine();
    Export_pyste_src_DrawableGravity();
    Export_pyste_src_DrawableFont();
    Export_pyste_src_DrawableFillRule();
    Export_pyste_src_DrawableFillOpacity();
    Export_pyste_src_DrawableFillColor();
    Export_pyste_src_DrawableEllipse();
    Export_pyste_src_DrawableDashOffset();
    Export_pyste_src_DrawableDashArray();
    Export_pyste_src_DrawableCompositeImage();
    Export_pyste_src_DrawableColor();
    Export_pyste_src_DrawableClipPath();
    Export_pyste_src_DrawableCircle();
    Export_pyste_src_DrawableBezier();
    Export_pyste_src_DrawableArc();
    Export_pyste_src_DrawableAffine();
    Export_pyste_src_Drawable();
    Export_pyste_src_DecorationType();
    Export_pyste_src_Coordinate();
    Export_pyste_src_CompressionType();
    Export_pyste_src_CompositeOperator();
    Export_pyste_src_Color();
    Export_pyste_src_Blob();
    Export_pyste_src_ColorspaceType();
}
